@@ -60,9 +60,11 @@ def create_login(request):
     return login
 
 def get_idp(entity_id):
-    for idp in app_settings.IDENTITY_PROVIDERS:
-        if idp['ENTITY_ID'] == entity_id:
-            return idp
+    for adapter in get_adapters():
+        if hasattr(adapter, 'get_idp'):
+            idp = adapter.get_idp(entity_id)
+            if idp:
+                return idp
 
 def flatten_datetime(d):
     for key, value in d.iteritems():
@@ -93,9 +95,9 @@ def import_object(path):
     return getattr(module, name)
 
 @to_list
-def get_adapters(idp):
+def get_adapters(idp={}):
     idp = idp or {}
-    adapters = idp.get('ADAPTER') or app_settings.ADAPTER
+    adapters = idp.get('ADAPTER', []) + app_settings.ADAPTER
     for adapter in adapters:
         yield import_object(adapter)()
 
@@ -107,10 +109,11 @@ def get_values(saml_attributes, name):
         return (values,)
     return values
 
-
-
-def get_parameter(idp, name):
-    return idp.get(name) or getattr(app_settings, name)
+def get_setting(idp, name, default=None):
+    '''Get a parameter from an IdP specific configuration or from the main
+       settings.
+    '''
+    return idp.get(name) or getattr(app_settings, name, default=default)
 
 def create_logout(request):
     server = create_server(request)
@@ -129,7 +132,6 @@ def create_logout(request):
             'name_id_name_qualifier': name_id_name_qualifier,
             'name_id_sp_name_qualifier': name_id_sp_name_qualifier,
     })
-    print 'session_dump', session_dump
     logout = lasso.Logout(server)
     if not app_settings.PRIVATE_KEY:
         logout.setSignatureHint(lasso.PROFILE_SIGNATURE_HINT_FORBID)
