@@ -87,9 +87,6 @@ class LoginView(View):
                     content = [any.exportToXml() for any in value.any]
                     content = ''.join(content)
                     values.append(content.decode('utf8'))
-        attributes.update({
-            'issuer': name_id.nameQualifier or login.remoteProviderId,
-        })
         if login.nameIdentifier:
             name_id = login.nameIdentifier
             attributes.update({
@@ -98,6 +95,11 @@ class LoginView(View):
                 'name_id_name_qualifier': name_id.nameQualifier,
                 'name_id_sp_name_qualifier': name_id.spNameQualifier,
             })
+            attributes.update({
+                'issuer': name_id.nameQualifier
+            })
+        if 'issuer' not in attributes:
+            attributes['issuer'] = login.remoteProviderId
         authn_statement = login.assertion.authnStatement[0]
         if authn_statement.authnInstant:
             attributes['authn_instant'] = utils.iso8601_to_datetime(authn_statement.authnInstant)
